Crate dfwasm_template

Crate dfwasm_template 

Structs

Args
Location
Template

Enums

Block
The main structure of a block. This is not actually the type that is serialized/deserialized. Instead, it converts from/to [JSONBlock], which is friendlier with the JSON.
BracketDirection
BracketKind
CodeBlock
Item
ParamKind
Target
VariableScope

Functions

split_templates
Splits a list of templates into smaller templates if they are too large.